@@ -1,5 +1,7 @@
 """
-Main interface for ec2-instance-connect service type definitions.
+Type annotations for ec2-instance-connect service type definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/type_defs.html)
 
 Usage::
 
@@ -19,10 +21,12 @@ else:
 
 __all__ = ("SendSSHPublicKeyResponseTypeDef", "SendSerialConsoleSSHPublicKeyResponseTypeDef")
 
-SendSSHPublicKeyResponseTypeDef = TypedDict(
-    "SendSSHPublicKeyResponseTypeDef", {"RequestId": str, "Success": bool}, total=False
-)
 
-SendSerialConsoleSSHPublicKeyResponseTypeDef = TypedDict(
-    "SendSerialConsoleSSHPublicKeyResponseTypeDef", {"RequestId": str, "Success": bool}, total=False
-)
+class SendSSHPublicKeyResponseTypeDef(TypedDict, total=False):
+    RequestId: str
+    Success: bool
+
+
+class SendSerialConsoleSSHPublicKeyResponseTypeDef(TypedDict, total=False):
+    RequestId: str
+    Success: bool
